@@ -1,12 +1,12 @@
 import json
 import os
-from typing import List, Tuple, Union
+from typing import List, Literal, Tuple, Union
 
 import numpy as np
 
 from worker.data import math
 from worker.data.api import API
-from worker.data.enums import EventTypes, Environment
+from worker.data.enums import Environment, EventTypes
 from worker.data.wits import WITS
 from worker.exceptions import NotFound
 
@@ -85,7 +85,7 @@ def delete_collection_data_of_asset_id(asset_id: int, collections: Union[str, li
                 break
 
 
-def point_main_envs(env: str):
+def point_main_envs(env: Literal['qa', 'staging', 'production', 'local']):
     """
     The purpose of this function is to point main environment variables to
     the provided environment. This method updates the following environment
@@ -103,9 +103,11 @@ def point_main_envs(env: str):
     # validating the environment
     Environment(env)
 
-    api_url = os.getenv(f"API_ROOT_URL_{env}")
-    api_key = os.getenv(f"API_KEY_{env}")
-    cache_url = os.getenv(f"CACHE_URL_{env}")
+    env_all_caps = env.upper()
+
+    api_url = os.getenv(f"API_ROOT_URL_{env}") or os.getenv(f"API_ROOT_URL_{env_all_caps}")
+    api_key = os.getenv(f"API_KEY_{env}") or os.getenv(f"API_KEY_{env_all_caps}")
+    cache_url = os.getenv(f"CACHE_URL_{env}") or os.getenv(f"CACHE_URL_{env_all_caps}")
 
     if not all([api_url, api_key, cache_url]):
         raise ValueError("Missing environment variables!")
@@ -119,7 +121,7 @@ def point_main_envs(env: str):
     os.environ.update(new_envs)
 
 
-def setup_api_worker(env: str, app_name: str):
+def setup_api_worker(env: Literal['qa', 'staging', 'production', 'local'], app_name: str) -> API:
     """
     Set up the Corva API worker
     :param env: environment ['local', 'qa', 'staging', 'production']
@@ -129,8 +131,10 @@ def setup_api_worker(env: str, app_name: str):
     # validating the environment
     Environment(env)
 
-    api_url = os.getenv(f"API_ROOT_URL_{env}")
-    api_key = os.getenv(f"API_KEY_{env}")
+    env_all_caps = env.upper()
+
+    api_url = os.getenv(f"API_ROOT_URL_{env}") or os.getenv(f"API_ROOT_URL_{env_all_caps}")
+    api_key = os.getenv(f"API_KEY_{env}") or os.getenv(f"API_KEY_{env_all_caps}")
 
     options = {
         "api_url": api_url,
@@ -142,7 +146,7 @@ def setup_api_worker(env: str, app_name: str):
     return api_worker
 
 
-def setup_redis_worker(env: str) -> Tuple:
+def setup_redis_worker(env: Literal['qa', 'staging', 'production', 'local']):
     """
     Set up the Redis worker
     :param env: environment ['local', 'qa', 'staging', 'production']
@@ -151,7 +155,7 @@ def setup_redis_worker(env: str) -> Tuple:
     # validating the environment
     Environment(env)
 
-    cache_url = os.getenv(f"CACHE_URL_{env}")
+    cache_url = os.getenv(f"CACHE_URL_{env}") or os.getenv(f"CACHE_URL_{env.upper()}")
 
     import redis
     redis_worker = redis.Redis.from_url(cache_url, decode_responses=True)
