@@ -93,6 +93,19 @@ class Hole(SectionsMixin):
 
         return cased_hole
 
+    def get_open_hole(self):
+        """
+        Get the open sections of the hole.
+        :return:
+        """
+        open_hole = Hole()
+
+        for sec in self:
+            if sec.hole_type == HoleType.OPEN_HOLE:
+                open_hole.add_section(sec)
+
+        return open_hole
+
     def get_casing_bottom_depth(self):
         return self.get_cased_hole().get_bottom_depth()
 
